@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2006 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ for sourceview in "gtksourceview sourceview".split():
     except ImportError:
         pass
 
-version = "1.1.2"
+version = "1.1.4"
 
 # magic developer switch, changes some behaviour
 developer = 0
@@ -142,8 +142,8 @@ class ListWidget(gnomeglade.Component):
     def on_item_new_clicked(self, button):
         model = self.treeview.get_model()
         it = model.append()
-        model.set_value(it, 0, "label")
-        model.set_value(it, 2, "pattern")
+        model.set_value(it, 0, _("label"))
+        model.set_value(it, 2, _("pattern"))
         self._update_filter_string()
     def _get_selected(self):
         selected = []
@@ -244,11 +244,12 @@ class PreferencesDialog(gnomeglade.Component):
         self.draw_style[self.prefs.draw_style].set_active(1)
         self.toolbar_style[self.prefs.toolbar_style].set_active(1)
         # file filters
-        cols = [ ("Name", type("")), ("Active", type(0)), ("Pattern", type("")) ]
+        cols = [ (_("Name"), type("")), (_("Active"), type(0)), (_("Pattern"), type("")) ]
         self.filefilter = ListWidget( cols, self.prefs, "filters")
         self.file_filters_box.pack_start(self.filefilter.widget)
+        self.checkbutton_ignore_symlinks.set_active( self.prefs.ignore_symlinks)
         # text filters
-        cols = [ ("Name", type("")), ("Active", type(0)), ("Regex", type("")) ]
+        cols = [ (_("Name"), type("")), (_("Active"), type(0)), (_("Regex"), type("")) ]
         self.textfilter = ListWidget( cols, self.prefs, "regexes")
         self.text_filters_box.pack_start(self.textfilter.widget)
         self.checkbutton_ignore_blank_lines.set_active( self.prefs.ignore_blank_lines )
@@ -313,6 +314,8 @@ class PreferencesDialog(gnomeglade.Component):
     #
     # filters
     #
+    def on_checkbutton_ignore_symlinks_toggled(self, check):
+        self.prefs.ignore_symlinks = check.get_active()
     def on_checkbutton_ignore_blank_lines_toggled(self, check):
         self.prefs.ignore_blank_lines = check.get_active()
 
@@ -413,6 +416,7 @@ class MeldPreferences(prefs.Preferences):
         "save_encoding": prefs.Value(prefs.INT, 0),
         "draw_style": prefs.Value(prefs.INT,2),
         "toolbar_style": prefs.Value(prefs.INT,0),
+        "ignore_symlinks": prefs.Value(prefs.BOOL,0),
         "cvs_quiet": prefs.Value(prefs.BOOL, 1),
         "cvs_compression": prefs.Value(prefs.BOOL, 1),
         "cvs_compression_value": prefs.Value(prefs.INT, 3),
@@ -431,17 +435,31 @@ class MeldPreferences(prefs.Preferences):
         "color_inline_fg" : prefs.Value(prefs.STRING, "Red"),
         "color_edited_bg" : prefs.Value(prefs.STRING, "gray90"),
         "color_edited_fg" : prefs.Value(prefs.STRING, "Black"),
-        "filters" : prefs.Value(prefs.STRING, "Backups\t1\t#*# .#* ~* *~ *.{orig,bak,swp}\n" + \
-                                              "CVS\t1\tCVS\n" + \
-                                              "SVN\t1\t.svn\n" + \
-                                              "Binaries\t1\t*.{pyc,a,obj,o,so,la,lib,dll}\n" + \
-                                              "Media\t0\t*.{jpg,gif,png,wav,mp3,ogg,xcf,xpm}"),
-        "regexes" : prefs.Value(prefs.STRING, "CVS keywords\t0\t\$\\w+(:[^\\n$]+)?\$\n" + \
-                                              "C++ comment\t0\t//.*\n" + \
-                                              "C comment\t0\t/\*.*?\*/\n" + \
-                                              "All whitespace\t0\t[ \\t\\r\\f\\v]*\n" + \
-                                              "Leading whitespace\t0\t^[ \\t\\r\\f\\v]*\n" + \
-                                              "Script comment\t0\t#.*"),
+        "filters" : prefs.Value(prefs.STRING,
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Backups\t1\t#*# .#* ~* *~ *.{orig,bak,swp}\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("CVS\t1\tCVS\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("SVN\t1\t.svn\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Monotone\t1\tMT\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Binaries\t1\t*.{pyc,a,obj,o,so,la,lib,dll}\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Media\t0\t*.{jpg,gif,png,wav,mp3,ogg,xcf,xpm}")),
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            "regexes" : prefs.Value(prefs.STRING, _("CVS keywords\t0\t\$\\w+(:[^\\n$]+)?\$\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("C++ comment\t0\t//.*\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("C comment\t0\t/\*.*?\*/\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("All whitespace\t0\t[ \\t\\r\\f\\v]*\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Leading whitespace\t0\t^[ \\t\\r\\f\\v]*\n") + \
+            #TRANSLATORS: translate this string ONLY to the first "\t", leave it and the following parts intact
+            _("Script comment\t0\t#.*")),
         "ignore_blank_lines" : prefs.Value(prefs.BOOL, 1)
     }
 
@@ -543,10 +561,12 @@ class MeldApp(gnomeglade.GnomeApp):
         else:
             self.statusbar.task_progress.set_fraction(0)
         if self.scheduler.tasks_pending():
+            self.toolbar_stop.set_sensitive(1)
             return 1
         else:
             self.statusbar.set_task_status("")
             self.idle_hooked = 0
+            self.toolbar_stop.set_sensitive(0)
             return 0
 
     def on_scheduler_runnable(self, sched):
@@ -635,6 +655,12 @@ class MeldApp(gnomeglade.GnomeApp):
 
     def on_menu_redo_activate(self, *extra):
         self.current_doc().on_redo_activate()
+
+    def on_menu_refresh_activate(self, *extra):
+        self.current_doc().on_refresh_activate()
+
+    def on_menu_reload_activate(self, *extra):
+        self.current_doc().on_reload_activate()
   
     def on_menu_find_activate(self, *extra):
         self.current_doc().on_find_activate()
@@ -709,6 +735,8 @@ class MeldApp(gnomeglade.GnomeApp):
             i = self.notebook.page_num( page.widget )
             assert(i>=0)
             self.notebook.remove_page(i)
+            if self.notebook.get_n_pages() == 0:
+                self.widget.set_title("Meld")
 
     def on_file_changed(self, srcpage, filename):
         for c in self.notebook.get_children():
@@ -829,7 +857,7 @@ def main():
     sys.stdout = Unbuffered(sys.stdout)
     args = sys.argv[1:]
 
-    if len(args) >= 2:
+    if args:
         if "-h" in args or "--help" in args:
             print usage_string
             return
